
import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;
import java.util.LinkedList;
import java.util.ListIterator;
import java.util.concurrent.atomic.AtomicLong;

/**
 * Implementación de la interfaz {@link InterfazServMaestro}
 * @author Alberto
 */
public class ImpInterfazServMaestro extends UnicastRemoteObject implements InterfazServMaestro {
	private static final long serialVersionUID = 1L;
	/**
	 * Cuenta el número de que se han abierto a lo largo de la vida del servidor. Cuando se registra una partida,
	 * el identificador que se le asigna es el número de partidas abiertas en ese momento.
	 */
	private AtomicLong numPartidas;
	private LinkedList<DatosServidorPartida> lista;
	
	public ImpInterfazServMaestro() throws RemoteException {
		numPartidas = new AtomicLong(0);
		lista = new LinkedList<DatosServidorPartida>();
	}
	
	@Override
	public long registrarServidor(DatosServidorPartida datos) throws RemoteException {
		long id = -1;
		
		if(!lista.contains(datos)) {
			System.out.println("Registrando partida: " + datos.toString());
			id = numPartidas.getAndIncrement();
			datos.setId(id);
			lista.add(datos);
		}
		
		return id;
	}
	
	@Override
	public boolean finPartida(DatosPartida datos) throws RemoteException {
		boolean result = false;
		
		ListIterator<DatosServidorPartida> it = lista.listIterator();
		while(it.hasNext() && !result) {
			DatosServidorPartida dsp = it.next();
			
			if(dsp.getId() == datos.getId()) {
				// registro de los datos
				// ...
				System.out.println("Eliminando partida: " + datos.toString());
				it.remove();
				result = true;
			}
		}
		
		return result;
	}

	@Override
	public LinkedList<DatosServidorPartida> consultarPartidas() throws RemoteException {
		return lista;
	}
}
