
import java.rmi.*;
import java.util.LinkedList;

/**
 * Interfaz que define los métodos para la comunicación con el servidor maestro, tanto desde un servidor de partidas
 * como desde un cliente de juego.
 * @author Alberto
 */
public interface InterfazServMaestro extends Remote {
	/**
	 * Registra una partida en el servidor maestro.
	 * @param datos Los datos del servidor que aloja la partida.
	 * @return El identificador asignado a la partida.
	 * @throws RemoteException
	 */
	public long registrarServidor(DatosServidorPartida datos) throws RemoteException;
	
	/**
	 * Elimina una partida previamente registrada y almacena en el servidor maestro los datos de la partida que
	 * se ha jugado.
	 * @param datos Los datos de la partida a finalizar.
	 * @return True si se cierra correctamente, false si la partida no estaba registrada.
	 * @throws RemoteException
	 */
	public boolean finPartida(DatosPartida datos) throws RemoteException;
	
	/**
	 * Devuelve una lista enlazada que contiene datos de las partidas activas.
	 * @return La lista de partidas.
	 * @throws RemoteException
	 */
	public LinkedList<DatosServidorPartida> consultarPartidas() throws RemoteException;
}
